<?php

/**
 * @package         Google Structured Data
 * @version         5.1.2 Free
 *
 * @author          Tassos Marinos <info@tassos.gr>
 * @link            http://www.tassos.gr
 * @copyright       Copyright © 2022 Tassos Marinos All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
 */

namespace GSD\Schemas\Schemas;

// No direct access
defined('_JEXEC') or die;

use GSD\Helper;

class Service extends \GSD\Schemas\Base
{   
    /**
     * A key => value array with properties that needs to be renamed
     *
     * @var mixed
     */
    protected $rename_properties = [
        'provider_country'       => 'addressCountry',
        'provider_streetAddress' => 'streetAddress',
        'provider_city'          => 'addressLocality',
        'provider_addressRegion' => 'addressRegion',
        'provider_postalCode'    => 'postalCode'
    ];
    
    /**
     * The HTML tags allowed to be used in certain schema properties, such as the headline and the description.
     *
     * @var string
     */
    protected $allowed_HTML_tags = '<p><br><ul><li><h1><h2><h3><h4><h5><strong><em><b>';

    /**
     * Class constructor
     *
     * @param JRegistry $data The schema properties
     */
    public function __construct($data = null)
    {
        parent::__construct($data);
        $this->descCharLimit = 0;
    }

    /**
     * Return all the schema properties
     *
     * @return JRegistry
     */
    public function getProperties()
    {
        $props = [
            'offerPrice'     => Helper::formatPrice($this->data['offerPrice']),
            'provider_image' => Helper::cleanImage($this->data['provider_image']),
            'phone'          => $this->data['provider_phone'],
        ];

        $this->data->loadArray($props);

        return parent::getProperties();
    }
}